#ifndef NT2_INCLUDE_CONSTANTS_THIRDROOTEPS_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_THIRDROOTEPS_HPP_INCLUDED

#include <nt2/constant/include/constants/thirdrooteps.hpp>

#endif
